@@ -25,13 +25,19 @@ from beartype._check.checkmagic import (
     ARG_NAME_RAISE_EXCEPTION,
 )
 from beartype._conf.confcls import BeartypeConf
-from beartype._data.datatyping import (
+from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeStack,
 )
-from beartype._util.func.utilfunccodeobj import get_func_codeobj
+from beartype._util.func.utilfunccodeobj import (
+    get_func_codeobj,
+    # get_func_codeobj_or_none,
+)
 from beartype._util.func.utilfunctest import is_func_coro
-from beartype._util.func.utilfuncwrap import unwrap_func
+from beartype._util.func.utilfuncwrap import (
+    # unwrap_func_all,
+    unwrap_func_all_closures_isomorphic,
+)
 
 # ....................{ CLASSES                            }....................
 class BeartypeCall(object):
@@ -55,7 +61,7 @@ class BeartypeCall(object):
     ----------
     **This object cannot be used to communicate state between low-level
     memoized callables** (e.g.,
-    :func:`beartype._check.expr.exprmake.make_func_wrapper_code`) **and
+    :func:`beartype._check.code.codemake.make_func_wrapper_code`) **and
     higher-level callables** (e.g.,
     :func:`beartype._decor._wrap.wrapmain.generate_code`). Instead, memoized
     callables *must* return that state as additional return values up the call
@@ -308,7 +314,10 @@ class BeartypeCall(object):
         self.func_wrappee = func
 
         # Possibly unwrapped callable unwrapped from that callable.
-        self.func_wrappee_wrappee = unwrap_func(func)
+        # self.func_wrappee_wrappee = unwrap_func_all(func)
+        self.func_wrappee_wrappee = unwrap_func_all_closures_isomorphic(func)
+        # print(f'func_wrappee: {self.func_wrappee}')
+        # print(f'func_wrappee_wrappee: {self.func_wrappee_wrappee}')
 
         # Possibly wrapped callable code object.
         self.func_wrappee_codeobj = get_func_codeobj(
