@@ -94,6 +94,30 @@ See Also
     as an essential sanity check on that runtime-specific set.
 '''
 
+# ....................{ STRINGS                            }....................
+TYPE_BUILTIN_FAKE_PYCAPSULE_NAME = 'PyCapsule'
+'''
+Unqualified classname of the **PyCapsule type** (i.e., the type of all opaque
+values encapsulating ``void*`` pointers in C extensions).
+
+Caveats
+----------
+**Python currently publishes *no* official PyCapsule type.** A little-known
+technique to access the ``PyCapsule`` type from pure-Python code *does* exist
+but is sufficiently non-portable to render that technique inadvisable in the
+general case, which means :mod:`beartype`. This global enables an alternate
+technique in the :func:`beartype._util.cls.utilclstest.is_type_builtin` tester
+known to be portable across Python versions and various platforms.
+
+See Also
+----------
+https://stackoverflow.com/a/62258339/2809027
+    StackOverflow answer strongly inspiring this global.
+https://stackoverflow.com/a/60319462/2809027
+    StackOverflow answer introducing an alternate non-portable technique for
+    obtaining the PyCapsule type itself.
+'''
+
 # ....................{ TUPLES                             }....................
 # Types of *ALL* objects that may be decorated by @beartype, intentionally
 # listed in descending order of real-world prevalence for negligible efficiency
