@@ -11,10 +11,12 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
+from beartype.typing import Iterator
+from beartype._util.func.utilfunccodeobj import get_func_codeobj_name
+from contextlib import contextmanager
 
 # ....................{ SETS                               }....................
-#FIXME: Rename to "METHOD_NAMES_DUNDER_BINARY" for clarity.
-METHOD_NAMES_BINARY_DUNDER = frozenset((
+METHOD_NAMES_DUNDER_BINARY = frozenset((
     '__add__',
     '__and__',
     '__cmp__',
