@@ -34,7 +34,7 @@ from beartype.roar import (
 )
 from beartype.typing import NoReturn
 from beartype._check.checkmagic import ARG_NAME_TYPISTRY
-from beartype._check.expr._exprsnip import (
+from beartype._check.code._codesnip import (
     PEP_CODE_HINT_FORWARDREF_UNQUALIFIED_PLACEHOLDER_PREFIX,
     PEP_CODE_HINT_FORWARDREF_UNQUALIFIED_PLACEHOLDER_SUFFIX,
 )
@@ -74,7 +74,7 @@ from beartype._util.hint.pep.proposal.pep484585.utilpep484585func import (
     reduce_hint_pep484585_func_return)
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585ref import (
     get_hint_pep484585_forwardref_classname_relative_to_object)
-from beartype._check.conv.convsanify import sanify_hint_root_func
+from beartype._check.convert.convsanify import sanify_hint_root_func
 from beartype._util.hint.utilhinttest import is_hint_ignorable
 from beartype._util.kind.utilkinddict import update_mapping
 from beartype._util.text.utiltextmunge import replace_str_substrs
@@ -339,15 +339,15 @@ def _code_check_args(bear_call: BeartypeCall) -> str:
     #calling the enumerate() builtin here) AFTER* refactoring @beartype to
     #generate callable-specific wrapper signatures.
 
-    # For the name of each parameter accepted by this callable and the
+    # For the 0-based index of each parameter accepted by this callable and the
     # "ParameterMeta" object describing this parameter (in declaration order)...
     for arg_index, arg_meta in enumerate(iter_func_args(
-        # Possibly lowest-level wrappee underlying the possibly
-        # higher-level wrapper currently being decorated by the @beartype
-        # decorator. The latter typically fails to convey the same callable
-        # metadata conveyed by the former -- including the names and kinds
-        # of parameters accepted by the possibly unwrapped callable. This
-        # renders the latter mostly useless for our purposes.
+        # Possibly lowest-level wrappee underlying the possibly higher-level
+        # wrapper currently being decorated by the @beartype decorator. The
+        # latter typically fails to convey the same callable metadata conveyed
+        # by the former -- including the names and kinds of parameters accepted
+        # by the possibly unwrapped callable. This renders the latter mostly
+        # useless for our purposes.
         func=bear_call.func_wrappee_wrappee,
         func_codeobj=bear_call.func_wrappee_wrappee_codeobj,
         is_unwrap=False,
@@ -481,9 +481,8 @@ def _code_check_args(bear_call: BeartypeCall) -> str:
                 exception=exception,
                 #FIXME: Embed the kind of parameter as well (e.g.,
                 #"positional-only", "keyword-only", "variadic positional"),
-                #ideally by improving the existing
-                #prefix_beartypeable_arg() function to introspect this
-                #kind from that callable's code object.
+                #ideally by improving the existing prefix_beartypeable_arg()
+                #function to introspect this kind from the callable code object.
                 target_str=prefix_beartypeable_arg(
                     func=bear_call.func_wrappee, arg_name=arg_name),
             )
