@@ -166,10 +166,10 @@ def callable_cached(func: _CallableT) -> _CallableT:
     assert callable(func), f'{repr(func)} not callable.'
 
     # Avoid circular import dependencies.
-    from beartype._util.func.utilfuncwrap import unwrap_func
+    from beartype._util.func.utilfuncwrap import unwrap_func_all
 
     # Lowest-level wrappee callable wrapped by this wrapper callable.
-    func_wrappee = unwrap_func(func)
+    func_wrappee = unwrap_func_all(func)
 
     # If this wrappee accepts variadic arguments, raise an exception.
     if is_func_arg_variadic(func_wrappee):
@@ -308,7 +308,7 @@ def method_cached_arg_by_id(func: _CallableT) -> _CallableT:
 
     **This decorator is only intended to decorate a method whose sole argument
     is guaranteed to be a memoized singleton** (e.g.,
-    :class:`beartype.door.TypeHint` singletons). In this case, the object
+    :class:`beartype.door.TypeHint` singleton). In this case, the object
     identifier of that argument uniquely identifies that argument across *all*
     calls to that method -- enabling this decorator to memoize that method.
     Conversely, if that argument is *not* guaranteed to be a memoized singleton,
@@ -377,10 +377,10 @@ def method_cached_arg_by_id(func: _CallableT) -> _CallableT:
     assert callable(func), f'{repr(func)} not callable.'
 
     # Avoid circular import dependencies.
-    from beartype._util.func.utilfuncwrap import unwrap_func
+    from beartype._util.func.utilfuncwrap import unwrap_func_all
 
     # Lowest-level wrappee callable wrapped by this wrapper callable.
-    func_wrappee = unwrap_func(func)
+    func_wrappee = unwrap_func_all(func)
 
     # If this wrappee accepts either zero, one, *OR* three or more flexible
     # parameters (i.e., parameters passable as either positional or keyword
@@ -390,7 +390,7 @@ def method_cached_arg_by_id(func: _CallableT) -> _CallableT:
         func_args_len_flexible=2,
         exception_cls=_BeartypeUtilCallableCachedException,
         # Avoid unnecessary callable unwrapping as a negligible optimization.
-        is_unwrapping=False,
+        is_unwrap=False,
     )
     # Else, this wrappee accepts exactly one flexible parameter.
 
