@@ -13,20 +13,23 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
 from beartype.typing import (
-    TYPE_CHECKING,
     Any,
 )
-from beartype._util.func.utilfunccodeobj import (
-    get_func_codeobj_or_none)
-from beartype._util.hint.utilhintfactory import TypeHintTypeFactory
-from beartype._util.mod.lib.utiltyping import import_typing_attr_or_fallback
-from beartype._data.datatyping import (
+from beartype._data.hint.datahintfactory import TypeGuard
+from beartype._data.hint.datahinttyping import (
     Codeobjable,
     TypeException,
 )
+from beartype._util.func.arg.utilfuncargtest import (
+    is_func_arg_variadic_positional,
+    is_func_arg_variadic_keyword,
+)
+from beartype._util.func.utilfunccodeobj import (
+    get_func_codeobj_or_none,
+)
 from collections.abc import (
     Callable,
-    Generator,
+    # Generator,
 )
 from inspect import (
     CO_ASYNC_GENERATOR,
@@ -34,40 +37,6 @@ from inspect import (
     CO_GENERATOR,
 )
 
-#FIXME: DRY violation. This logic is duplicated from the
-#"beartype.door._doorcheck" submodule. Ideally, this should be aggregated in
-#"beartype.typing" for public reuse.
-
-# Portably import the PEP 647-compliant "typing.TypeGuard" type hint factory
-# first introduced by Python >= 3.10, regardless of the current version of
-# Python and regardless of whether this submodule is currently being subject to
-# static type-checking or not. Praise be to MIT ML guru and stunning Hypothesis
-# maintainer @rsokl (Ryan Soklaski) for this brilliant circumvention. \o/
-#
-# Usage of this factory is a high priority. Hinting the return of the
-# is_bearable() tester with a type guard created by this factory effectively
-# coerces that tester in an arbitrarily complete type narrower and thus type
-# parser at static analysis time, substantially reducing complaints from static
-# type-checkers in end user code deferring to that tester.
-#
-# If this submodule is currently being statically type-checked (e.g., mypy),
-# intentionally import from the third-party "typing_extensions" module rather
-# than the standard "typing" module. Why? Because doing so eliminates Python
-# version complaints from static type-checkers (e.g., mypy, pyright). Static
-# type-checkers could care less whether "typing_extensions" is actually
-# installed or not; they only care that "typing_extensions" unconditionally
-# defines this type factory across all Python versions, whereas "typing" only
-# conditionally defines this type factory under Python >= 3.10. *facepalm*
-if TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-# Else, this submodule is currently being imported at runtime by Python. In this
-# case, dynamically import this factory from whichever of the standard "typing"
-# module *OR* the third-party "typing_extensions" module declares this factory,
-# falling back to the builtin "bool" type if none do.
-else:
-    TypeGuard = import_typing_attr_or_fallback(
-        'TypeGuard', TypeHintTypeFactory(bool))
-
 # ....................{ CONSTANTS                          }....................
 FUNC_NAME_LAMBDA = '<lambda>'
 '''
@@ -364,17 +333,52 @@ def is_func_python(func: object) -> TypeGuard[Callable]:
     Returns
     ----------
     bool
-        :data:`True` only if this object is a pure-Python callable
+        :data:`True` only if this object is a pure-Python callable.
     '''
 
     # Return true only if a pure-Python code object underlies this object.
     # C-based callables are associated with *NO* code objects.
     return get_func_codeobj_or_none(func) is not None
 
+
+def is_func_wrapper(func: Any) -> TypeGuard[Callable]:
+    '''
+    :data:`True` only if the passed object is a **callable wrapper** (i.e.,
+    object created by the standard :func:`functools.wraps` decorator for
+    wrapping a pure-Python callable with additional functionality defined by a
+    higher-level decorator).
+
+    Note that this tester returns :data:`True` for both pure-Python and C-based
+    callable wrappers. As an example of the latter, the standard
+    :func:`functools.lru_cache` decorator creates and returns low-level C-based
+    callable wrappers of the private type :class:`functools._lru_cache_wrapper`
+    wrapping pure-Python callables.
+
+    Parameters
+    ----------
+    func : object
+        Object to be inspected.
+
+    Returns
+    ----------
+    bool
+        :data:`True` only if this object is a callable wrapper.
+    '''
+
+    # Return true only if this object defines a dunder attribute uniquely
+    # specific to the @functools.wraps decorator.
+    #
+    # Technically, *ANY* callable (including non-wrappers *NOT* created by the
+    # @functools.wraps decorator) could trivially define this attribute; ergo,
+    # this invites the possibility of false positives. Pragmatically, doing so
+    # would violate ad-hoc standards and real-world practice across the
+    # open-source ecosystem; ergo, this effectively excludes false positives.
+    return hasattr(func, '__wrapped__')
+
 # ....................{ TESTERS ~ descriptor               }....................
 def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     '''
-    ``True`` only if the passed object is a **C-based unbound class method
+    :data:`True` only if the passed object is a **C-based unbound class method
     descriptor** (i.e., method decorated by the builtin :class:`classmethod`
     decorator, yielding a non-callable instance of that :class:`classmethod`
     decorator class implemented in low-level C and accessible via the
@@ -399,7 +403,7 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     Returns
     ----------
     bool
-        ``True`` only if this object is a C-based unbound class method
+        :data:`True` only if this object is a C-based unbound class method
         descriptor.
     '''
 
@@ -409,8 +413,8 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
 
 def is_func_property(func: Any) -> TypeGuard[property]:
     '''
-    ``True`` only if the passed object is a **C-based unbound property method
-    descriptor** (i.e., method decorated by the builtin :class:`property`
+    :data:`True` only if the passed object is a **C-based unbound property
+    method descriptor** (i.e., method decorated by the builtin :class:`property`
     decorator, yielding a non-callable instance of that :class:`property`
     decorator class implemented in low-level C and accessible as a class rather
     than instance attribute).
@@ -432,7 +436,7 @@ def is_func_property(func: Any) -> TypeGuard[property]:
     Returns
     ----------
     bool
-        ``True`` only if this object is a pure-Python property.
+        :data:`True` only if this object is a pure-Python property.
     '''
 
     # We rejoice in the shared delight of one-liners.
@@ -662,3 +666,150 @@ def is_func_sync_generator(func: object) -> TypeGuard[Callable]:
         # synchronous generator.
         func_codeobj.co_flags & CO_GENERATOR != 0
     )
+
+# ....................{ TESTERS : nested                   }....................
+def is_func_nested(func: Callable) -> bool:
+    '''
+    :data:`True` only if the passed callable is **nested** (i.e., a pure-Python
+    callable declared in the body of another pure-Python callable).
+
+    Parameters
+    ----------
+    func : Callable
+        Callable to be inspected.
+
+    Returns
+    ----------
+    bool
+        :data:`True` only if this callable is nested.
+    '''
+
+    # Return true only if either...
+    return (
+        # That callable is a closure (in which case that closure is necessarily
+        # nested inside another callable) *OR*...
+        #
+        # Note that this tester intentionally tests for whether that callable is
+        # a closure first, as doing so efficiently reduces to a constant-time
+        # attribute test -- whereas the following test for non-closure nested
+        # callables inefficiently requires a linear-time string search.
+        is_func_closure(func) or
+        # The fully-qualified name of that callable contains one or more "."
+        # delimiters, each signifying a nested lexical scope. Since *ALL*
+        # callables (i.e., both pure-Python and C-based) define a non-empty
+        # "__qualname__" dunder variable containing at least their unqualified
+        # names, this simplistic test is guaranteed to be safe.
+        #
+        # Note this tester intentionally tests for the general-purpose existence
+        # of a "." delimiter rather than the special-cased existence of a
+        # ".<locals>." placeholder substring. Why? Because there are two types
+        # of nested callables:
+        # * Non-methods, which are lexically nested in a parent callable whose
+        #   scope encapsulates all previously declared local variables. For
+        #   unknown reasons, the unqualified names of nested non-method
+        #   callables are *ALWAYS* prefixed by ".<locals>." in their
+        #   "__qualname__" variables:
+        #       >>> from collections.abc import Callable
+        #       >>> def muh_parent_callable() -> Callable:
+        #       ...     def muh_nested_callable() -> None: pass
+        #       ...     return muh_nested_callable
+        #       >>> muh_nested_callable = muh_parent_callable()
+        #       >>> muh_parent_callable.__qualname__
+        #       'muh_parent_callable'
+        #       >>> muh_nested_callable.__qualname__
+        #       'muh_parent_callable.<locals>.muh_nested_callable'
+        # * Methods, which are lexically nested in the scope encapsulating all
+        #   previously declared class variables (i.e., variables declared in
+        #   class scope and thus accessible as method annotations). For unknown
+        #   reasons, the unqualified names of methods are *NEVER* prefixed by
+        #   ".<locals>." in their "__qualname__" variables: e.g.,
+        #       >>> from typing import ClassVar
+        #       >>> class MuhClass(object):
+        #       ...    # Class variable declared in class scope.
+        #       ...    muh_class_var: ClassVar[type] = int
+        #       ...    # Instance method annotated by this class variable.
+        #       ...    def muh_method(self) -> muh_class_var: return 42
+        #       >>> MuhClass.muh_method.__qualname__
+        #       'MuhClass.muh_method'
+        '.' in func.__qualname__
+    )
+
+# ....................{ TESTERS ~ nested : closure         }....................
+def is_func_closure(func: Any) -> TypeGuard[Callable]:
+    '''
+    :data:`True` only if the passed callable is a **closure** (i.e., nested
+    callable accessing one or more variables declared by the parent callable
+    also declaring that callable).
+
+    Note that all closures are necessarily nested callables but that the
+    converse is *not* necessarily the case. In particular, a nested callable
+    accessing *no* variables declared by the parent callable also declaring that
+    callable is *not* a closure; it's simply a nested callable.
+
+    Parameters
+    ----------
+    func : Callable
+        Callable to be inspected.
+
+    Returns
+    ----------
+    bool
+        :data:`True` only if this callable is a closure.
+    '''
+
+    # Return true only if that callable defines the closure-specific
+    # "__closure__" dunder variable whose value is either:
+    # * If that callable is a closure, a tuple of zero or more cell variables.
+    # * If that callable is a pure-Python non-closure, "None".
+    # * If that callable is C-based, undefined.
+    return getattr(func, '__closure__', None) is not None
+
+
+def is_func_closure_isomorphic(func: Any) -> TypeGuard[Callable]:
+    '''
+    :data:`True` only if the passed object is an **isomorphic decorator
+    closure** (i.e., closure both defined and returned by a decorator such that
+    that closure isomorphically preserves both the number and types of all
+    passed parameters and returns, implemented as a closure accepting only a
+    variadic positional argument and a variadic keyword argument).
+
+    This tester enables callers to detect when a user-defined callable has been
+    decorated by an isomorphic decorator, which constitutes *most* real-world
+    decorators of interest.
+
+    Caveats
+    ----------
+    **This tester is merely a heuristic** -- albeit a reasonably robust
+    heuristic likely to succeed in almost all real-world use cases. Nonetheless,
+    this tester *could* return false positives and negatives in edge cases.
+
+    Parameters
+    ----------
+    func : object
+        Object to be inspected.
+
+    Returns
+    ----------
+    bool
+        :data:`True` only if this object is an isomorphic decorator closure.
+    '''
+
+    # If the passed callable is *NOT* a closure, immediately return false.
+    if not is_func_closure(func):
+        return False
+    # Else, that callable is a closure.
+
+    # Code object underlying that callable as is (rather than possibly unwrapped
+    # to another code object entirely) if that callable is pure-Python *OR*
+    # "None" otherwise (i.e., if that callable is C-based).
+    func_codeobj = get_func_codeobj_or_none(func)
+
+    # Return true only if...
+    return (
+        # That callable is pure-Python *AND*...
+        func_codeobj is not None and
+        # That callable accepts a variadic positional argument *AND*...
+        is_func_arg_variadic_positional(func_codeobj) and
+        # That callable accepts a variadic keyword argument.
+        is_func_arg_variadic_keyword(func_codeobj)
+    )
