@@ -17,7 +17,7 @@ from beartype.typing import (
     Optional,
     Tuple,
 )
-from beartype._data.datatyping import TypeException
+from beartype._data.hint.datahinttyping import TypeException
 from beartype._data.hint.pep.sign.datapepsigns import HintSignGeneric
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.cache.pool.utilcachepoollistfixed import (
@@ -110,15 +110,18 @@ def get_hint_pep484585_generic_bases_unerased(
     exception_prefix: str = '',
 ) -> Tuple[object, ...]:
     '''
-    Tuple of all **unerased pseudo-superclasses** (i.e., PEP-compliant objects
-    originally listed as superclasses prior to their implicit type erasure
-    under :pep:`560`) of the passed :pep:`484`- or :pep:`585`-compliant
-    **generic** (i.e., class superficially subclassing at least one
-    PEP-compliant type hint that is possibly *not* an actual class) if this
-    object is a generic *or* raise an exception otherwise (i.e., if this object
-    is either not a class *or* is a class subclassing no non-class
+    Tuple of the one or more **unerased pseudo-superclasses** (i.e.,
+    PEP-compliant objects originally listed as superclasses prior to their
+    implicit type erasure under :pep:`560`) of the passed :pep:`484`- or
+    :pep:`585`-compliant **generic** (i.e., class superficially subclassing at
+    least one PEP-compliant type hint that is possibly *not* an actual class) if
+    this object is a generic *or* raise an exception otherwise (i.e., if this
+    object is either not a class *or* is a class subclassing no non-class
     PEP-compliant objects).
 
+    This getter is guaranteed to return a non-empty tuple. By definition, a
+    generic is a type subclassing one or more generic superclasses.
+
     This getter is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
     to an efficient one-liner.
@@ -152,17 +155,17 @@ def get_hint_pep484585_generic_bases_unerased(
     ``__orig_mro__`` dunder attribute listing the original method resolution
     order (MRO) of that subclass had that tuple *not* been modified.
 
-    Naturally, :pep:`560` did no such thing. The original MRO remains
-    obfuscated and effectively inaccessible. While computing that MRO would
-    technically be feasible, doing so would also be highly non-trivial,
-    expensive, and fragile. Instead, this function retrieves *only* the tuple
-    of :mod:`typing`-specific pseudo-superclasses that this object's class
-    originally attempted (but failed) to subclass.
+    Naturally, :pep:`560` did no such thing. The original MRO remains obfuscated
+    and effectively inaccessible. While computing that MRO would technically be
+    feasible, doing so would also be highly non-trivial, expensive, and fragile.
+    Instead, this function retrieves *only* the tuple of :mod:`typing`-specific
+    pseudo-superclasses that this object's class originally attempted (but
+    failed) to subclass.
 
-    You are probably now agitatedly cogitating to yourself in the darkness:
-    "But @leycec: what do you mean :pep:`560`? Wasn't :pep:`560` released
-    *after* :pep:`484`? Surely no public API defined by the Python stdlib would
-    be so malicious as to silently alter the tuple of base classes listed by a
+    You are probably now agitatedly cogitating to yourself in the darkness: "But
+    @leycec: what do you mean :pep:`560`? Wasn't :pep:`560` released *after*
+    :pep:`484`? Surely no public API defined by the Python stdlib would be so
+    malicious as to silently alter the tuple of base classes listed by a
     user-defined subclass?"
 
     As we've established both above and elsewhere throughout the codebase,
@@ -185,22 +188,19 @@ def get_hint_pep484585_generic_bases_unerased(
     types listed as base classes in user-defined subclasses as follows:
 
     * All base classes whose origin is a builtin container (e.g.,
-      ``typing.List[T]``) are reduced to that container (e.g.,
-      :class:`list`).
+      ``typing.List[T]``) are reduced to that container (e.g., :class:`list`).
     * All base classes derived from an abstract base class declared by the
       :mod:`collections.abc` subpackage (e.g., ``typing.Iterable[T]``) are
-      reduced to that abstract base class (e.g.,
-      ``collections.abc.Iterable``).
+      reduced to that abstract base class (e.g., ``collections.abc.Iterable``).
     * All surviving base classes that are parametrized (e.g.,
       ``typing.Generic[S, T]``) are stripped of that parametrization (e.g.,
       :class:`typing.Generic`).
 
-    Since there exists no counterpart to the :class:`typing.Generic`
-    superclass, the :mod:`typing` module preserves that superclass in
-    unparametrized form. Naturally, this is useless, as an unparametrized
-    :class:`typing.Generic` superclass conveys no meaningful type information.
-    All other superclasses are reduced to their non-:mod:`typing`
-    counterparts: e.g.,
+    Since there exists no counterpart to the :class:`typing.Generic` superclass,
+    the :mod:`typing` module preserves that superclass in unparametrized form.
+    Naturally, this is useless, as an unparametrized :class:`typing.Generic`
+    superclass conveys no meaningful type information. All other superclasses
+    are reduced to their non-:mod:`typing` counterparts: e.g.,
 
         .. code-block:: python
 
@@ -216,13 +216,13 @@ def get_hint_pep484585_generic_bases_unerased(
         (typing.List[T], typing.Iterable[T], typing.Generic[T])
         # Guess which we prefer?
 
-    So, we prefer the generally useful ``__orig_bases__`` dunder tuple over
-    the generally useless ``__mro__`` dunder tuple. Note, however, that the
-    latter *is* still occasionally useful and thus occasionally returned by
-    this getter. For inexplicable reasons, **single-inherited protocols**
-    (i.e., classes directly subclassing *only* the :pep:`544`-compliant
-    :attr:`typing.Protocol` abstract base class (ABC)) are *not* subject to
-    type erasure and thus constitute a notable exception to this heuristic:
+    So, we prefer the generally useful ``__orig_bases__`` dunder tuple over the
+    generally useless ``__mro__`` dunder tuple. Note, however, that the latter
+    *is* still occasionally useful and thus occasionally returned by this
+    getter. For inexplicable reasons, **single-inherited protocols** (i.e.,
+    classes directly subclassing *only* the :pep:`544`-compliant
+    :attr:`typing.Protocol` abstract base class (ABC)) are *not* subject to type
+    erasure and thus constitute a notable exception to this heuristic:
 
         .. code-block:: python
 
@@ -234,8 +234,8 @@ def get_hint_pep484585_generic_bases_unerased(
         AttributeError: type object 'UserDefinedProtocol' has no attribute
         '__orig_bases__'
 
-    Welcome to :mod:`typing` hell, where even :mod:`typing` types lie broken
-    and misshapen on the killing floor of overzealous theory-crafting purists.
+    Welcome to :mod:`typing` hell, where even :mod:`typing` types lie broken and
+    misshapen on the killing floor of overzealous theory-crafting purists.
 
     Parameters
     ----------
@@ -279,12 +279,6 @@ def get_hint_pep484585_generic_bases_unerased(
          object)
     '''
 
-    #FIXME: Refactor get_hint_pep585_generic_bases_unerased() and
-    #get_hint_pep484_generic_bases_unerased() to:
-    #* Raise "BeartypeDecorHintPep484585Exception" instead.
-    #* Accept an optional "exception_prefix" parameter, which we should pass
-    #  here.
-
     # Tuple of either...
     #
     # Note this implicitly raises a "BeartypeDecorHintPepException" if this
@@ -293,11 +287,23 @@ def get_hint_pep484585_generic_bases_unerased(
     hint_pep_generic_bases_unerased = (
         # If this is a PEP 585-compliant generic, all unerased
         # pseudo-superclasses of this PEP 585-compliant generic.
-        get_hint_pep585_generic_bases_unerased(hint)
+        #
+        # Note that this unmemoized getter accepts keyword arguments.
+        get_hint_pep585_generic_bases_unerased(
+            hint=hint,
+            exception_cls=exception_cls,
+            exception_prefix=exception_prefix,
+        )
         if is_hint_pep585_generic(hint) else
         # Else, this *MUST* be a PEP 484-compliant generic. In this case, all
         # unerased pseudo-superclasses of this PEP 484-compliant generic.
-        get_hint_pep484_generic_bases_unerased(hint)
+        #
+        # Note that this memoized getter prohibits keyword arguments.
+        get_hint_pep484_generic_bases_unerased(
+            hint,
+            exception_cls,
+            exception_prefix,
+        )
     )
 
     # If this generic subclasses *NO* pseudo-superclass, raise an exception.
@@ -317,7 +323,7 @@ def get_hint_pep484585_generic_bases_unerased(
     # Return this tuple of these pseudo-superclasses.
     return hint_pep_generic_bases_unerased
 
-# ....................{ GETTERS                            }....................
+# ....................{ GETTERS ~ type                     }....................
 #FIXME: Unit test us up, please.
 def get_hint_pep484585_generic_type(
     # Mandatory parameters.
@@ -351,10 +357,10 @@ def get_hint_pep484585_generic_type(
     Caveats
     ----------
     **This getter returns false positives in edge cases.** That is, this getter
-    returns non-``None`` values for both generics and non-generics (notably,
+    returns non-``None`` values for both generics and non-generics -- notably,
     non-generics defining the ``__origin__`` dunder attribute to an
-    isinstanceable class). Callers *must* perform subsequent tests to
-    distinguish these two cases.
+    isinstanceable class. Callers *must* perform subsequent tests to distinguish
+    these two cases.
 
     Parameters
     ----------
@@ -403,12 +409,12 @@ def get_hint_pep484585_generic_type(
 def get_hint_pep484585_generic_type_or_none(hint: object) -> Optional[type]:
     '''
     Either the passed :pep:`484`- or :pep:`585`-compliant **generic** (i.e.,
-    class superficially subclassing at least one PEP-compliant type hint that
-    is possibly *not* an actual class) if **unsubscripted** (i.e., indexed by
-    *no* arguments or type variables), the unsubscripted generic underlying
-    this generic if **subscripted** (i.e., indexed by one or more child type
-    hints and/or type variables), *or* ``None`` otherwise (i.e., if this hint
-    is *not* a generic).
+    class superficially subclassing at least one PEP-compliant type hint that is
+    possibly *not* an actual class) if **unsubscripted** (i.e., indexed by *no*
+    arguments or type variables), the unsubscripted generic underlying this
+    generic if **subscripted** (i.e., indexed by one or more child type hints
+    and/or type variables), *or* ``None`` otherwise (i.e., if this hint is *not*
+    a generic).
 
     Specifically, this getter returns (in order):
 
@@ -425,10 +431,10 @@ def get_hint_pep484585_generic_type_or_none(hint: object) -> Optional[type]:
     Caveats
     ----------
     **This getter returns false positives in edge cases.** That is, this getter
-    returns non-``None`` values for both generics and non-generics (notably,
+    returns non-``None`` values for both generics and non-generics -- notably,
     non-generics defining the ``__origin__`` dunder attribute to an
-    isinstanceable class). Callers *must* perform subsequent tests to
-    distinguish these two cases.
+    isinstanceable class. Callers *must* perform subsequent tests to distinguish
+    these two cases.
 
     Parameters
     ----------
@@ -472,6 +478,156 @@ def get_hint_pep484585_generic_type_or_none(hint: object) -> Optional[type]:
     # Return the "None" singleton.
     return None
 
+# ....................{ FINDERS                            }....................
+def find_hint_pep484585_generic_module_base_first(
+    # Mandatory parameters.
+    hint: object,
+    module_name: str,
+
+    # Optional parameters.
+    exception_cls: TypeException = BeartypeDecorHintPep484585Exception,
+    exception_prefix: str = '',
+) -> type:
+    '''
+    Iteratively find and return the first **unerased superclass** (i.e.,
+    unerased pseudo-superclass that is an actual superclass) transitively
+    defined under the third-party package or module with the passed name
+    subclassed by the unsubscripted generic type underlying the passed
+    :pep:`484`- or :pep:`585`-compliant **generic** (i.e., object that may *not*
+    actually be a class despite subclassing at least one PEP-compliant type hint
+    that also may *not* actually be a class).
+
+    This finder is intentionally *not* memoized (e.g., by the
+    :func:`callable_cached` decorator). Although doing so *would* dramatically
+    improve the efficiency of this finder, doing so:
+
+    * Would require all passed parameters be passed positionally, which becomes
+      rather cumbersome given the number of requisite parameters.
+    * Is (currently) unnecessary, as all callers of this function are themselves
+      already memoized.
+
+    Motivation
+    ----------
+    This finder is typically called to reduce **descriptive generics** (i.e.,
+    generics defined in third-party packages intended to be used *only* as
+    descriptive type hints rather than actually instantiated as objects as most
+    generics are) to the isinstanceable classes those generics describe.
+    Although the mere existence of descriptive generics should be considered to
+    be a semantic (if not syntactic) violation of :pep:`484`, the widespread
+    proliferation of descriptive generics leaves :mod:`beartype` with little
+    choice but to grin wanly and bear the pain they subject us to. As example,
+    this finder is currently called elsewhere to:
+
+    * Reduce Pandera type hints (e.g., `pandera.typing.DataFrame[...]`) to the
+      Pandas types they describe (e.g., `pandas.DataFrame`).
+    * Reduce NumPy type hints (e.g., `numpy.typing.NDArray[...]`) to the
+      NumPy types they describe (e.g., `numpy.ndarray`).
+
+    See examples below for further discussion.
+
+    Parameters
+    ----------
+    hint : object
+        Generic type hint to be inspected.
+    module_name : str
+        Fully-qualified name of the third-party package or module to find the
+        first class in this generic type hint of.
+    exception_cls : TypeException
+        Type of exception to be raised. Defaults to
+        :exc:`BeartypeDecorHintPep484585Exception`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing the representation of this object in
+        the exception message. Defaults to the empty string.
+
+    Returns
+    ----------
+    type
+        First unerased superclass transitively defined under this package or
+        module subclassed by the unsubscripted generic type underlying this
+        generic type hint.
+
+    Examples
+    ----------
+        >>> from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
+        ...     find_hint_pep484585_generic_base_first_in_module)
+
+        # Reduce a Pandera type hint to the Pandas type it describes.
+        >>> from pandera import DataFrameModel
+        >>> from pandera.typing import DataFrame
+        >>> class MuhModel(DataFrameModel): pass
+        >>> find_hint_pep484585_generic_base_first_in_module(
+        ...     hint=DataFrame[MuhModel], module_name='pandas', ...)
+        <class 'pandas.DataFrame'>
+    '''
+    assert isinstance(module_name, str), f'{repr(module_name)} not string.'
+
+    # Avoid circular import dependencies.
+    from beartype._util.mod.utilmodget import get_object_module_name_or_none
+
+    # Either:
+    # * If this generic is unsubscripted, this unsubscripted generic type as is.
+    # * If this generic is subscripted, the unsubscripted generic type
+    #   underlying this subscripted generic (e.g., the type
+    #   "pandera.typing.pandas.DataFrame" given the type hint
+    #   "pandera.typing.DataFrame[...]").
+    hint_type = get_hint_pep484585_generic_type(
+        hint=hint,
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
+
+    # Fully-qualified name of the module to be searched for suffixed by a "."
+    # delimiter. This is a micro-optimization improving lookup speed below.
+    module_name_prefix = f'{module_name}.'
+
+    # Tuple of the one or more unerased pseudo-superclasses which this
+    # unsubscripted generic type originally subclassed prior to type erasure.
+    #
+    # Note that we could also inspect the method-resolution order (MRO) of this
+    # type via the "hint.__mro__" dunder tuple, but that doing so would only
+    # needlessly reduce the efficiency of the following iteration by
+    # substantially increasing the number of iterations required to find the
+    # desired superclass and thus the worst-case complexity of that iteration.
+    hint_type_bases = get_hint_pep484585_generic_bases_unerased(
+        hint=hint,
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
+
+    # For each unerased pseudo-superclass of this unsubscripted generic type...
+    for hint_base in hint_type_bases:
+        # If this pseudo-superclass is *NOT* an actual superclass, silently
+        # ignore this non-superclass and continue to the next pseudo-superclass.
+        if not isinstance(hint_base, type):
+            continue
+        # Else, this pseudo-superclass is an actual superclass.
+
+        # Fully-qualified name of the module declaring this superclass if any
+        # *OR* "None" otherwise (i.e., if this type is only defined in-memory).
+        hint_base_module_name = get_object_module_name_or_none(hint_base)
+
+        # If this module exists *AND* either...
+        if hint_base_module_name and (
+            # This module is the desired module itself *OR*...
+            hint_base_module_name == module_name_prefix or
+            # This module is a submodule of the desired module...
+            hint_base_module_name.startswith(module_name_prefix)
+        # Then return this superclass.
+        ):
+            # print(f'Found generic {repr(hint)} type {repr(hint_type)} "{module_name}" superclass {repr(hint_base)}!')
+            return hint_base
+        # Else, this is *NOT* the desired module. In this case, continue to the
+        # next superclass.
+    # Else, *NO* superclass of this generic resides in the desired module.
+
+    # Raise an exception of the passed type.
+    raise exception_cls(
+        f'{exception_prefix}PEP 484 or 585 generic {repr(hint)} '
+        f'type {repr(hint_type)} subclasses no "{module_name}" type '
+        f'(i.e., type with module name prefixed by "{module_name}" not '
+        f'found in method resolution order (MRO) {repr(hint_type.__mro__)}).'
+    )
+
 # ....................{ ITERATORS                          }....................
 #FIXME: Unit test us up, please.
 def iter_hint_pep484585_generic_bases_unerased_tree(
@@ -503,7 +659,7 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
     visited by this BFS should be visitable as is via whatever external parent
     BFS is currently iterating over the tree of all transitive type hints (e.g.,
     our code generation algorithm implemented by the
-    :func:`beartype._check.expr.exprmake.make_func_wrapper_code` function).
+    :func:`beartype._check.code.codemake.make_func_wrapper_code` function).
     That's how we transitively visit all other kinds of type hints, right?
     Sadly, that simple solution fails to scale to all possible edge cases that
     arise with generics. Why? Because our code generation algorithm sensibly
@@ -532,12 +688,12 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
         >>> class UserProtocol(t.Protocol[t.AnyStr]): pass
         >>> class UserSubprotocol(UserProtocol[str], t.Protocol): pass
         >>> UserSubprotocol.__orig_bases__
-        (UserProtocol[str], typing.Protocol)
+        (UserProtocol[str], typing.Protocol)  # <-- good
         >>> UserProtocolUnerased = UserSubprotocol.__orig_bases__[0]
         >>> UserProtocolUnerased is UserProtocol
         False
         >>> isinstance(UserProtocolUnerased, type)
-        False
+        False  # <-- bad
 
     :pep:`585`-compliant generics suffer no such issues:
 
@@ -548,7 +704,7 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
         (UserGeneric[int],)
         >>> UserGenericUnerased = UserSubgeneric.__orig_bases__[0]
         >>> isinstance(UserGenericUnerased, type)
-        True
+        True  # <-- good
         >>> UserGenericUnerased.__mro__
         (UserGeneric, list, object)
         >>> is_hint_pep585_builtin(UserGenericUnerased)
@@ -627,7 +783,7 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
 
     # Initialize this list to these direct pseudo-superclasses of this generic.
     hint_bases[0:hint_bases_index_past_last] = hint_bases_direct
-    # print(f'generic pseudo-superclasses [initial]: {repr(hint_childs)}')
+    # print(f'generic pseudo-superclasses [initial]: {repr(hint_bases_direct}')
 
     # While the 0-based index of the next visited pseudo-superclass does *NOT*
     # exceed that of the last pseudo-superclass in this list, there remains one
@@ -649,7 +805,7 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
             # this pith against the generic subclassing this superclass and thus
             # this superclass as well in an isinstance() call (e.g., in the
             # "PEP484585_CODE_HINT_GENERIC_PREFIX" snippet leveraged by the
-            # "beartype._check.expr.exprmake" submodule).
+            # "beartype._check.code.codemake" submodule).
             hint_base_sign is None or
             # An ignorable PEP-compliant type hint...
             is_hint_ignorable(hint_base)
@@ -706,17 +862,15 @@ def iter_hint_pep484585_generic_bases_unerased_tree(
                 yield hint_base
         # Else, this pseudo-superclass is ignorable.
         # else:
-        #     print(f'Ignoring generic {hint} base...')
-        #     print(f'Is generic {hint} base type? {isinstance(hint_base, type)}')
+        #     print(f'Ignoring generic {repr(hint)} base {repr(hint_base)}...')
+        #     print(f'Is generic {hint} base {repr(hint_base)} type? {isinstance(hint_base, type)}')
 
-        # Nullify the previously visited pseudo-superclass in
-        # this list for safety.
+        # Nullify the previously visited pseudo-superclass in this list.
         hint_bases[hint_bases_index_curr] = None
 
-        # Increment the 0-based index of the next visited
-        # pseudo-superclass in this list *BEFORE* visiting that
-        # pseudo-superclass but *AFTER* performing all other
-        # logic for the currently visited pseudo-superclass.
+        # Increment the 0-based index of the next visited pseudo-superclass in
+        # this list *BEFORE* visiting that pseudo-superclass but *AFTER*
+        # performing all other logic for the current pseudo-superclass.
         hint_bases_index_curr += 1
 
     # Release this list. Pray for salvation, for we find none here.
