@@ -13,7 +13,7 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.typing import Optional
-from beartype._data.datatyping import BeartypeableT
+from beartype._data.hint.datahinttyping import BeartypeableT
 from beartype._util.utilobject import (
     get_object_name,
     get_object_type_name,
@@ -25,9 +25,9 @@ def label_beartypeable_kind(
     obj: BeartypeableT,  # pyright: ignore[reportInvalidTypeVarUse]
 ) -> str:
     '''
-    Human-readable label describing the **kind** (i.e.,
-    single concise noun synopsizing the category of) the passed **beartypeable**
-    (i.e., object that is currently being or has already been decorated by the
+    Human-readable label describing the **kind** (i.e., single concise noun
+    synopsizing the category of) of the passed **beartypeable** (i.e., object
+    that is currently being or has already been decorated by the
     :func:`beartype.beartype` decorator).
 
     Parameters
@@ -173,14 +173,9 @@ def label_callable(
 
     # Avoid circular import dependencies.
     from beartype._util.func.arg.utilfuncargget import (
-        get_func_args_len_flexible)
+        get_func_args_flexible_len)
     from beartype._util.func.utilfunccodeobj import get_func_codeobj
-    from beartype._util.func.utilfunctest import (
-        is_func_async_generator,
-        is_func_coro,
-        is_func_lambda,
-        is_func_sync_generator,
-    )
+    from beartype._util.func.utilfunctest import is_func_lambda
 
     # Substring prefixing the string to be returned, typically identifying the
     # specialized type of that callable if that callable has a specialized type.
@@ -203,7 +198,7 @@ def label_callable(
         # Substring preceding the string to be returned.
         func_label_prefix = (
             f'lambda function of '
-            f'{get_func_args_len_flexible(func_codeobj)} argument(s)'
+            f'{get_func_args_flexible_len(func_codeobj)} argument(s)'
         )
 
         # If the caller failed to request an explicit contextualization, default
