@@ -20,11 +20,10 @@ from beartype.door._doorcheck import (
     die_if_unbearable,
     is_bearable,
 )
-from beartype.door._doormeta import _TypeHintMeta
+from beartype.door._cls.doormeta import _TypeHintMeta
 from beartype.door._doortest import die_unless_typehint
 from beartype.door._doortyping import T
 from beartype.typing import (
-    TYPE_CHECKING,
     Any,
     FrozenSet,
     Generic,
@@ -37,7 +36,8 @@ from beartype._conf.confcls import (
     BEARTYPE_CONF_DEFAULT,
     BeartypeConf,
 )
-from beartype._data.datatyping import CallableMethodGetitemArg
+from beartype._data.hint.datahintfactory import TypeGuard
+from beartype._data.hint.datahinttyping import CallableMethodGetitemArg
 from beartype._util.cache.utilcachecall import (
     method_cached_arg_by_id,
     property_cached,
@@ -47,20 +47,7 @@ from beartype._util.hint.pep.utilpepget import (
     get_hint_pep_origin_or_none,
     get_hint_pep_sign_or_none,
 )
-from beartype._util.hint.utilhintfactory import TypeHintTypeFactory
 from beartype._util.hint.utilhinttest import is_hint_ignorable
-from beartype._util.mod.lib.utiltyping import import_typing_attr_or_fallback
-
-# ....................{ HINTS                              }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-# CAUTION: Synchronize with similar logic in "beartype.door._doorcheck". See
-# the head of that submodule for detailed commentary.
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-if TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-else:
-    TypeGuard = import_typing_attr_or_fallback(
-        'TypeGuard', TypeHintTypeFactory(bool))
 
 # ....................{ SUPERCLASSES                       }....................
 #FIXME: Subclass all applicable "collections.abc" ABCs for explicitness, please.
@@ -395,7 +382,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
     @property
     def is_ignorable(self) -> bool:
         '''
-        ``True`` only if this type hint is **ignorable** (i.e., conveys
+        :data:`True` only if this type hint is **ignorable** (i.e., conveys
         *no* meaningful semantics despite superficially appearing to do so).
 
         While one might expect the set of all ignorable type hints to be both
@@ -465,12 +452,12 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
           unignorable in most type hinting contexts.
         * And frankly many more. And... *now we know why this tester exists.*
 
-        This tester method is memoized for efficiency.
+        This property is memoized for efficiency.
 
         Returns
         ----------
         bool
-            ``True`` only if this type hint is ignorable.
+            :data:`True` only if this type hint is ignorable.
         '''
 
         # Mechanic: Somebody set up us the bomb.
