@@ -47,7 +47,10 @@ from beartype.roar._roarexc import (
     BeartypeCaveNoneTypeOrKeyException as BeartypeCaveNoneTypeOrKeyException,
     BeartypeCaveNoneTypeOrMutabilityException as BeartypeCaveNoneTypeOrMutabilityException,
     BeartypeClawException as BeartypeClawException,
-    BeartypeClawRegistrationException as BeartypeClawRegistrationException,
+    BeartypeClawHookException as BeartypeClawHookException,
+    BeartypeClawImportException as BeartypeClawImportException,
+    BeartypeClawImportAstException as BeartypeClawImportAstException,
+    BeartypeClawImportConfException as BeartypeClawImportConfException,
     BeartypeConfException as BeartypeConfException,
     BeartypeDoorException as BeartypeDoorException,
     BeartypeDoorNonpepException as BeartypeDoorNonpepException,
