@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -12,6 +12,25 @@ replacement for :class:`typing.Protocol` that can lead to significant
 performance improvements.
 '''
 
+# ....................{ TODO                               }....................
+#FIXME: *YIKES.* Our "beartype.typing.Protocol" implementation is broken yet
+#again -- but this time for @classmethod-decorated callables. Consider this:
+#    from beartype.typing import Protocol
+#    class BrokenProtocol(Protocol):
+#        @classmethod
+#        def broken_classmethod(cls) -> object:
+#            pass
+#
+#Now define an arbitrary class violating that protocol:
+#    class BrokenClass(object): pass
+#
+#Now attempt to demonstrate that this class violates that protocol:
+#    >>> isinstance(BrokenClass, BrokenProtocol)
+#    True  # <----- WAAAAAAAAAT
+#
+#This issue is almost certainly related to classmethods. We clearly never tested
+#that. Classmethods clearly require explicit handling and caching. *sigh*
+
 # ....................{ IMPORTS                            }....................
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_8,
@@ -273,7 +292,7 @@ if IS_PYTHON_AT_LEAST_3_8:
 
         def __instancecheck__(cls, inst: Any) -> bool:
             '''
-            ``True`` only if the passed object is a **structural subtype**
+            :data:`True` only if the passed object is a **structural subtype**
             (i.e., satisfies the protocol defined by) the passed protocol.
 
             Parameters
@@ -286,7 +305,7 @@ if IS_PYTHON_AT_LEAST_3_8:
             Returns
             ----------
             bool
-                ``True`` only if this object satisfies this protocol.
+                :data:`True` only if this object satisfies this protocol.
             '''
 
             # Attempt to...
@@ -360,14 +379,12 @@ if IS_PYTHON_AT_LEAST_3_8:
                 # This attribute is either...
                 ) and (
                     # Undefined by the passed object *OR*...
-                    #
-                    # This method has been specifically "blocked" (i.e.,
-                    # ignored) by the passed object from being type-checked as
-                    # part of this protocol. For unknown and presumably
-                    # indefensible reasons, PEP 544 explicitly supports a
-                    # fragile, unreadable, and error-prone idiom enabling
-                    # objects to leave methods "undefined." What this madness!
                     not hasattr(inst, cls_attr_name) or
+                    # Defined by the passed object as a "blocked" (i.e., omitted
+                    # from being type-checked as part of this protocol) method.
+                    # For unknown and indefensible reasons, PEP 544 explicitly
+                    # supports this fragile, unreadable, and error-prone idiom
+                    # enabling objects to leave methods "undefined." What this!?
                     (
                         #FIXME: Unit test this up, please.
                         # A callable *AND*...
