@@ -26,7 +26,7 @@ from beartype.vale._util._valeutilsnip import (
     VALE_CODE_INDENT_1,
 )
 from beartype.vale._core._valecore import BeartypeValidator
-from beartype._data.datatyping import LexicalScope
+from beartype._data.hint.datahinttyping import LexicalScope
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.kind.utilkinddict import update_mapping
 from beartype._util.func.utilfuncscope import add_func_scope_attr
