@@ -20,7 +20,7 @@ from beartype._util.text.utiltextmagic import CODE_INDENT_1
 VALE_CODE_INDENT_1 = f'{{indent}}{CODE_INDENT_1}'
 '''
 Code snippet prefixed by the placeholder substring ``"{indent}"`` (which the
-:func:`beartype._check.expr.exprmake.make_func_wrapper_code` replaces with
+:func:`beartype._check.code.codemake.make_func_wrapper_code` replaces with
 the indentation level required by the current beartype validator) followed by a
 single level of indentation.
 '''
